@@ -1,7 +1,7 @@
 # WWWTheme.pm - perl source for HTML::WWWTheme
 # 
-# Copyright (C) 1999 Chad Hogan <chogan@uvphys.phys.uvic.ca>
-# Copyright (C) 1999 Joint Astronomy Centre
+# Copyright (C) 2000 Chad Hogan <chogan@uvastro.phys.uvic.ca>
+# Copyright (C) 2000 Joint Astronomy Centre
 #
 # All rights reserved.
 # 
@@ -29,7 +29,7 @@ use Carp;
 
 use vars qw($VERSION);
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 # You're going to notice that $self->{"link"} is in quotation marks.
 # that's because I get an ambiguity error if I use it.  So, I made
@@ -42,7 +42,7 @@ sub new {
 	      nextlink          => "",
               lastlink          => "",
               uplink            => "",
-
+	      
 	      bgcolor           => "#FFFFFF",
 	      bgpicture         => "",
 	      alink             => "",
@@ -56,7 +56,8 @@ sub new {
               sidebartop        => "<A HREF=\"http://www.nowhere.com/\">Nowhere</a>",
               sidebarmenutitle  => "My Divisions",
               sidebarsearchbox  => "0", 
-              sidebarmenulinks  => [], 
+              sidebarmenulinks  => [],
+	      morelinkstitle    => "More links",
 	      usenavbar         => "", 
 	      configfile        => "", 
 	      startstring       => "<HTML><HEAD><TITLE>Nothing</TITLE></HEAD>",
@@ -64,12 +65,12 @@ sub new {
 	      searchtemplate    => "",
 	     }; 
   my $config; 
- 
+  
   if (@_)
     {
       GetConfiguration($self, @_) || carp "configuration failed! probably bad files." && return 0;
     }
-
+  
   bless $self, $type;
   return $self;
 }
@@ -104,8 +105,8 @@ sub MakeHeader
 q{
 <!-- HTML GENERATED BY HTML::WWWTheme
 ***********************************************************
-Copyright (C) 1999 Chad Hogan <chogan@uvphys.phys.uvic.ca>
-Copyright (C) 1999 Joint Astronomy Centre
+Copyright (C) 2000 Chad Hogan <chogan@uvastro.phys.uvic.ca>
+Copyright (C) 2000 Joint Astronomy Centre
 All Rights Reserved.
 HTML::WWWTheme is free software, licensed under the GNU General
 Public License as published by the Free Software Foundation.  Please
@@ -149,7 +150,7 @@ see the source code for details.
    <!--a spacer-->
 	  <IMG SRC="} . $self->{blankgif} . q{" alt="" width="1" height="1" vspace="17"><BR>
 
-	  <B>More links</B><BR><HR>
+	  <B>} . $self->{morelinkstitle} . q{</B><BR><HR>
 	  
  
 	  <TABLE CELLSPACING="0" CELLPADDING="0">
@@ -303,6 +304,7 @@ sub GetConfiguration
 	    
 	    ( /\@SIDEBARTOP\s*?=\s*?(.*?);/s )       && ($self->{sidebartop}       = $1);
 	    ( /\@SIDEBARMENUTITLE\s*?=\s*?(.*?);/s ) && ($self->{sidebarmenutitle} = $1);
+	    ( /\@MORELINKSTITLE\s*?=\s*?(.*?);/s )   && ($self->{morelinkstitle}   = $1);
 	    ( /\@SEARCHTEMPLATE\s*?=\s*?(.*?);/s )   && ($self->{searchtemplate}   = $1);
 	    ( /\@SIDEBARSEARCHBOX\s*?=\s*?(.*?);/s ) && ($self->{sidebarsearchbox} = $1);
 	    ( /\@SIDEBARCOLOR\s*?=\s*?(.*?);/s )     && ($self->{sidebarcolor}     = $1);
@@ -388,87 +390,94 @@ sub SetVLink
     return $self->{vlink};
 }
 
+sub SetMoreLinksTitle
+  {
+    my $self = shift;
+    $self->{morelinkstitle} = shift if (@_);
+    return $self->{morelinkstitle};
+  }
+
 sub SetSideBarTop
-{
+  {
     my $self = shift;
     $self->{sidebartop} = shift if (@_);
     return $self->{vlink};
-}
+  }
 
 sub SetSideBarMenuTitle
-{
+  {
     my $self = shift;
     $self->{sidebarmenutitle} = shift if (@_);
     return $self->{sidebarmenutitle};
-}
+  }
 
 sub SetSideBarSearchBox
-{
+  {
     my $self = shift;
     $self->{sidebarsearchbox} = shift if (@_);
     return $self->{sidebarsearchbox};
-}
+  }
 
 sub SetSideBarColor
-{
+  {
     my $self = shift;
     $self->{sidebarcolor} = shift if (@_);
     return $self->{sidebarcolor};
-}
+  }
 
 sub SetInfoLinks
-{
+  {
     my $self = shift;
     $self->{infolinks} = shift if (@_);
     return $self->{infolinks};
-}
+  }
 
 sub SetSideBarMenuLinks
-{
+  {
     my $self = shift;
     $self->{sidebarmenulinks} = shift if (@_);
     return $self->{sidebarmenulinks};
-}
+  }
 
 sub SetUseNavBar
-{
+  {
     my $self = shift;
     $self->{usenavbar} = shift if (@_);
     return $self->{usenavbar};
-}
+  }
 
 sub SetHTMLStartString
-{
+  {
     my $self = shift;
     $self->{startstring} = shift if (@_);
     return $self->{startstring};
-}
+  }
 
 sub SetHTMLEndString
-{
+  {
     my $self = shift;
     $self->{endstring} = shift if (@_);
     return $self->{endstring};
-}
+  }
 
 sub SetText
-{
+  {
     my $self = shift;
     $self->{text} = shift if (@_);
     return $self->{text};
-}
+  }
 
 sub StartHTML
-{
+  {
     my $self = shift;
     return $self->{startstring};
-}
+  }
 
 sub EndHTML
-{
+  {
     my $self = shift;
     return $self->{endstring};
-}
+  }
 
 
 
@@ -570,6 +579,7 @@ the same method:
  @SIDEBARMENUTITLE  (see SetSidebarMenuTitle() )
  @SIDEBARSEARCHBOX  (see SetSideBarSearchBox() )
  @SIDEBARCOLOR      (see SetSideBarColor() )
+ @MORELINKSTITLE    (see SetMoreLinksTitle() )
  @INFO              (see SetInfoLinks() )
  @SIDEBARMENULINKS  (see SetSideBarMenuLinks() )
 
@@ -633,6 +643,13 @@ a hex color code.
  $Theme->SetVLink("#FFCCFF");
  $Theme->SetLink ("#FFCCFF");
 
+=item SetMoreLinksTitle()
+
+Sets the "More links" title on the sidebar.  By default it says "More
+links", but you may want to change it something else.
+
+ $Theme->SetMoreLinksTitle("More useful links");
+
 =item SetHTMLStartString()
 
 Sets the HTML starting string.  This string should include the <HTML> opening tag,
@@ -795,8 +812,8 @@ L<Apache::SetWWWTheme>
 
 =head1 AUTHOR
 
-Copyright (C) 1999 Chad Hogan (chogan@uvphys.phys.uvic.ca).  
-Copyright (C) 1999 Joint Astronomy Centre
+Copyright (C) 2000 Chad Hogan (chogan@uvastro.phys.uvic.ca).  
+Copyright (C) 2000 Joint Astronomy Centre
 
 All rights reserved.  HTML::WWWTheme is free software;
 you can redistribute it and/or modify it under the terms of the GNU General Public
